# 第７章 カスタマイズ

## ７.１ カスタマイズの概要

&emsp;「カスタマイズ」とは、アプリケーションの使用環境を、ユーザーが好みにあわせて再設定することです。VZは、DEFファイルと呼ばれるテキストファイルを起動時に読み込みます。ここにはキーアサイン、メニュー、オプション、マクロ等が記述してあり、このファイルを編集することにより、各自の好みにあった操作環境に構築することができます。

&emsp;DEFファイルには2つの種類があります。一つは「VZ.DEF」に代表される、起動時に読み込むDEFファイルです。これがなければ、VZは起動しません。もう一つは、「BLOCK.DEF」や「GAME.DEF」などの「マクロファイル」です。これは必要に応じて後から読み込んで使います。用途が異なるだけで、書式等は全く同じです。一度、いろいろなDEFファイルをオープンして、中身をご覧になってください。

- Ver1.6では、ファイラー関連の定義を「VZFL.DEF」というファイルにまとめました。これがないと、ファイラーのメニューコマンドが使えません。

- 起動時に読み込むDEFファイルの指定方法については、「1.3 DEFファイル」で説明しました。

- 「-w」指定によりDEFファイルを VZ.COM へ取り込む機能は、Ver1.6では廃止されました。これは、コードとデータエリアを分離したために、VZ.COM へ出力できなくなったためです。

- 従来版では各機種版ごとにDEFファイルが用意されていましたが、Ver1.6では「VZ.DEF」と「VZE.DEF」（英語メッセージ）に統一しました。これは、機種ごとに「#if」文で条件分岐させる機能がついたためです。このため、DEFファイルのサイズが少し大きくなっていますが、従来版のようなサイズ制限はありませんので、ご安心ください。


## ７.２ DEFファイルの構造

&emsp;全てのDEFファイルは、次のような構造になっています。


	======== vz.def (v1.6) ========         ← タイトル行
	
	* C コマンドキー                         ← 各機能ヘッダ
	
	* F ファンクションキー表示
	
	...
	
	*                                       ← 終端マーク
	======== End of vz.def ========         ← エンドタイトル行


**【タイトル行】**<br>
&emsp;ファイルの先頭はタイトル行です。従来版ではこの行はオプション「St+」で画面に表示される以外、とくに意味はありませんでしたが、Ver1.6では非常に重要な意味をもちます。詳しくは「8.4 モジュール管理」をお読みください。このため、タイトル行は、次の書式で記述してください。

	============ zenhan.def 全角／半角変換 ============
	      ↑          ↑          ↑            ↑
	任意個の「=」 ファイル名   タイトル  	任意個の「=」

- 先頭は必ず「=」で始める。（「;」だと認識しない）
- ファイル名は大文字でも可。「.def」は省略可。


**【各機能ヘッダ】**<br>
&emsp;「*」で始まる行は、続く1文字の英字で、以下の10種類の機能のヘッダとなります。

|日本語表記|英語表記|
|---|---|
|* C コマンドキー|* Command keys|
|* F ファンクションキー表示|* Function key labels|
|* T テキストウィンドウ|* Text windows|
|* S システムメニュー|* System menu|
|* M マクロ|* Macros|
|* P メニュー|* Pop up menu|
|* O オプション|* Options|
|* A エイリアス|* Alias|
|* H ヒストリー|* History|
|* E その他|* Else|

**【終端マーク】**<br>
&emsp;「*」のみの行は、DEFファイルの終りを表しています。これ以降の記述は読みとばします。従って、エンドタイトル行はとくに意味がありません。

**【コメント】**<br>
&emsp;「;」で始まる行、および「*Alias *Histoy *Else」以外の項目の「;」から行末までは、コメントとして読みとばします。

- Ver1.6では、動作機種のシンボルで「#if ... #endif」のブロックIF文が使えます。これについては次節で説明します。



## ７.３ ブロックIF文

&emsp;複数の機種でVZを使う場合、キーアサインや表示属性の違い等の理由から、各機種ごとにDEFファイルを用意しなくてはなりませんでした。Ver1.6では、次のようなブロックIF文により、共通のDEFファイルで、動作マシンによって、読み込む内容を切り替えることが可能となりました。

	* C コマンドキー

	#if 98
	31	^W  ¥[**RLDN**]	:ロールアップ
	32	^Z  ¥[**RLUP**]	:ロールダウン
	...
	43	^QP		:直前のカーソル位置
	#else
	31	^W  ¥[**PGUP**]	:ロールアップ
	32	^Z  ¥[**PGDN**]	:ロールダウン
	...
	43	^QP ¥[**END**]	:直前のカーソル位置
	#endif

	* O オプション

	#if 98
	LC-			;編集時の行間空きモードの指定
	#elseif DOSV
	LC			;日本語モード時の最下行の予約
	VM0			;編集時のスクリーンモード
	#endif

	* E その他

	#if DOSV IBM AX
	12	"$(00,08,02,0B,04,05,06,07,38,09,3A,3B,3C,3D,3E,3F)"
	#endif


●各機種のシンボルは、次のとおりです。<br>

|機種|シンボル|VZファイル|
|---|---|---|
|98版|98|VZ.COM|
|DOS／V版|DOSV|VZIBM.COM, VZIBMJ.COM|
|J3100版|J31|VZJ31.COM|
|AX版|AX|VZAX.COM|
|PS55版|PS55|VZ55.COM|
|US版|US|VZUS.COM|

●文字列の比較の際、大文字、小文字は区別しません。また、複数のシンボルをスペースで区切って指定することもできます。<br>

●使用できる条件文のキーワードは、次の6つです。使い方については、VZ.DEFを参照してください。<br>

	#if
	#ifn
	#else
	#endif
	#elseif
	#elseifn

※ キーワードは、小文字で記述しなくてはなりません。<br>

- ＃if文はネストできます。
- ＃if文は、必ず行頭で指定しなくてはなりません。行頭にスペースを入れてインデントすることもできません。
- ＃if文は、DEFファイル中のどこにも記述できます。



## ７.４ DEFファイルの書式

&emsp;各機能ごとの書式について説明します。
### ■ C コマンドキー
&emsp;コマンドキーの割り当て、およびそのヘルプメッセージを記述します。

［書式］

	00   {<prefix key>}   [;<comment>]
	<n> [<key1>][<key2>] [:<message>] [;<comment>]

|項目|説明|
|---|---|
|〈n〉|コマンド番号（01～99）|
|〈key1〉|コマンドキー定義1|
|〈key2〉|コマンドキー定義2|
|〈prefix key〉|2ストロークキーの先頭キー（最大6個）|
|〈message〉|ヘルプメッセージ|
|〈comment〉|コメント|

&emsp;コマンドキーとして、次のキーが指定でき、各々別の機能を割り当てられます。

	^<英字キー>  @<英字キー>  <prefix><英字キー>
	[特殊キー]  ¥[特殊キー]  ^[特殊キー]  @[特殊キー]

**【98版】**<br>
|記号|キー|
|---|---|
|^|[**CTRL**]|
|¥|[**SHIFT**]|
|@|[**GRPH**]|
|<英字キー>|[@] [**A**]～[**Z**] [**[**] [**¥**] [**]**] [**^**] [**_**]（40h～5Fh）|
|[特殊キー]|[**RLUP**] [**RLDN**] [**INS**] [**DEL**] [**UP**] [<--] [-->] [**DOWN**] [**CLR**] [**HELP**] [**ESC**] [**TAB**] [**BS**] [**CR**] [**NFER**] [**F01**]～[**F15**]|
|〈prefix〉|^<英字キー> @<英字キー> [特殊キー]|

**【IBM版】**<br>
|記号|キー|
|---|---|
|^|[**Ctrl**]|
|¥|[**Shift**]|
|@|[**Alt**]|
|<英字キー>|[@] [**A**]～[**Z**] [**[**] [**¥**] [**]**] [**^**] [**_**]（40h～5Fh）|
|[特殊キー]|[**PGDN**] [**PGUP**] [**INS**] [**DEL**] [**UP**] [<--] [-->] [**DOWN**] [**HOME**] [**END**] [**ESC**] [**TAB**] [**BS**] [**CR**] [**F01**]～[**F12**]|
|〈prefix〉|^<英字キー> @<英字キー> [特殊キー]|

●制限事項<br>
(A) [特殊キー]と、3番目以降の<prefix>キーは、各々1つしか指定できません。<br>
(B) 3番目以降の<prefix>キーは、先に指定しなければなりません。<br>
(C) 01～08番のコマンドには、<prefix><英字キー>は指定できません。<br>
(D)  98版の@<英字キー>、[**NFER**]は、EZKEYを組み込まないと使用できません。

［誤った記述例］

	00	^Q ^K [ESC]    :2ストロ...    ';'の誤り
	11	[HOME] ^[<--]  :論理行頭      制限(A)
	70	@O [ESC]O      :O ファイ...   制限(B)
	02	^KM            :キーボー...   制限(C)

●以下のキーは、BIOSの関係で入力できません。<br>

 【98版】^[**CLR**] @[**CLR**] @[**F01**]～@[**F15**]  @[ @] @_<br>
 【J31版】^[**ESC**] ^[**TAB**] ^[**BS**] ^[**INS**] ^[**DEL**] @[特殊キー] @<英記号>

### ■ F ファンクションキー表示
&emsp;ファンクションキーの表示ラベルを記述します。
［書式］

（98版、J-3100版）

	"<F1>","<F2>", ... ,"<F10>"	← [**F1**]～[**F10**]

&emsp;  2行目&emsp;     ：[**Shift**]+[**Fn**]

（IBM版）

	"<F1>","<F2>", ... ,"<F12>"	← [**Shift**]+[**F1**]～[**F10**]

&emsp;  2行目&emsp;     ：[**Shift**]+[**Fn**]<br>
&emsp;  3行目&emsp;     ：[**Ctrl**]+[**Fn**]<br>
&emsp;  4行目&emsp;     ：[**Alt**]+[**Fn**]

※ "<Fn>"のラベルは最大5文字（J-3100版のみ6文字）<br>

### ■ T テキストウィンドウ
&emsp;文字列入力ウィンドウのタイトル、サイズを記述します。

［書式］

	"<ttl>",<width> [;<comment>]

	    <ttl>       :ウィンドウのタイトル
	    <width>     :ウィンドウの横サイズ
	    <comment>   :コメント

システムで使用する14種類の文字列入力ウィンドウを順次記述します。


●文字列内の制御文字<br>

&emsp;文字列中では、「$」に続いて、つぎの制御文字が使えます。

	$"		'"'
	$$		'$'
	$0～$7		表示色
	$!		リバース
	$a?		「オプションA?」の表示色（?は英字）
	$an		テキストの表示色
	$p?		「変数P?」の示す文字列
	$pc		コマンド名
	$pn		カレントドライブ名
	$pd		カレントディレクトリ
	$po		検索オプション  (※)
	$??		「変数??」の10進表示
	$lc		表示行数
	$ht		編集テキストのタブカラム数
	$(hh,hh,hh,..)	16進コード指定（hhは16進数）
	$[**n**] $[n,c]	文字列をn個の文字c（省略時は0）で埋める (※)

&emsp;　　**※ はVer1.6で追加されました。**

［例］

	66	^KL		:L 表示行数切替え ($lc)
	"【入力ファイル】 <$pd>",40
	15 ^KI "T タブの切替え   ($ht)"
	8	$6$pd>

### ■ P メニュー ／ S システムメニュー
&emsp;マクロメニューとシステムメニューを記述します。

［書式］

	<n> "[<ttl>]",<width>,<items>[,<value width>][,-1] [;<comment>]
	     { ["<item>"] [,#nn|&nn|!nn|<opt>] }

	    <n>           :メニュー番号（システム:1～9、マクロ:1～98）
	    <ttl>         :メニューのタイトル
	    <width>       :メニューの横サイズ
	    <items>       :メニューアイテムの個数
	    <value width> :パラメータのカラム数
	    <comment>     :コメント
	    <item>        :アイテムメッセージ
	    #nn           :コマンド番号（nnは2桁の10進数）
	    &nn           :マクロ番号
	    !nn           :メニュー番号
	    <opt>         :オプション

**【システムメニュー】**<br>
&emsp;システムメニューは、コマンドまたはファイラーから使用されるメニューで、必ず定義する必要があります。特定のオプションを選択するメニューは、メニュー項目の数を変更してはいけません。

**【マクロメニュー】**<br>
&emsp;マクロメニューは、マクロ中で使用するメニューで、自由に定義して使用できます。定義したメニューは、マクロまたは他のメニューから、「!nn」で呼び出すことができます。

●マクロメニューのタイトル（<ttl>）を省略した場合は、<br>
- マクロから呼び出された場合 ････････ マクロのタイトル
- 他のメニューから呼び出された場合 ･･ 呼び出したアイテムメッセージ<br>
がタイトルとなります。


●メニューの各アイテムメッセージの後に以下のような記述をすると、そのメニューを選択して各種機能を実行できます。<br>

**【コマンド番号（#nn）】**<br>
&emsp;nn番のコマンドを実行します。アイテムメッセージ（<item>）を省略すると、「* C コマンドキー」で記述したヘルプメッセージを表示します。

**【マクロ番号（&nn）】**<br>
&emsp;nn番のマクロをコールします。アイテムメッセージ（<item>）を省略すると、コールするマクロのタイトルを表示します。

**【メニュー番号（!nn）】**<br>
&emsp;nn番のメニューを表示します。

**【オプション（<opt>）】**<br>
&emsp;指定オプションがスイッチオプションならスイッチのON／OFF、その他のオプションなら、ウィンドウを表示し、値を入力します。

●通常、スイッチの状態は 『ON』、『OFF』 で表示されますが、その他のメッセージを表示したい場合は、アイテムメッセージ中に、次のような書式でスイッチメッセージを記述してください。<br>

［書式］

	"<item><TAB><OFF sw><SPACE><ON sw>"

［例］

	"N 行番号モード<TAB>論理 表示",Dn

### ■ M マクロ
&emsp;マクロプログラムを記述します。

［書式］

	<n> <key> "<ttl>" <statement>（グローバルマクロ）
	<n>: <statement>	（ローカルマクロ）

	    <n>           :マクロ番号（1～89）
	    <key>         :マクロキー
	    <ttl>         :マクロのタイトル
	    <statement>   :マクロ定義の本体

&emsp;ローカルマクロは、他のマクロからコールされる、いわばサブルーチンです。<statement>はマクロ定義の本体で、行頭が「数字」または「*」の行までを、一つのプログラムと認識します。メモリに格納する際にスペース、タブ、改行、コメントは取り払われます。マクロに関する詳しい説明は、次章でおこないます。

### ■ O オプション
&emsp;起動時オプションを記述します。

［書式］

	<opt>[n|+|-]	[;<comment>]

	    <opt>         :オプション
	    <comment>     :コメント

&emsp;全オプションの機能については、次節で説明します。

### ■ A エイリアス
&emsp;コマンドラインで使用するエイリアス定義を記述します。

［書式］

	<atom><ｽﾍﾟｰｽ><command>

	    <atom>        :エイリアス名
	    <command>     :コマンド

&emsp;エイリアス機能については「6-2 エイリアス」をご覧ください。

### ■ H ヒストリー
&emsp;ヒストリーバッファの初期文字列を記述します。

［書式］

	:string | :file | :command
	{ <word> | "...." }

&emsp;行頭の「:」に続く一文字の英字（s|f|c）で、3種類のヒストリーバッファを選択し、その後に文字列を記述します。

	    string        :検索・置換・複写文字列バッファ
	    file          :ファイル名バッファ
	    command       :コマンドラインバッファ

&emsp;各文字列はスペースまたは改行で区切ります。文字列中にスペースを指定したい場合は、文字列を「"」でくくってください。ヒストリー機能については、「4-4 ヒストリー機能」をご覧ください。

### ■ E その他
&emsp;その他の13種類のパス名、文字列、表示属性を記述します。

［書式］

	<1～10> <string>

<string>の後にコメントを加えることはできません。

&emsp;各項目の機能は、次のとおりです。

|#|文字列|説明|
|---|---|---|
|1|vzfl|2番目以降に読み込むDEFファイル<br>　→「1.3 DEFファイル」|
|2|editfile|プロファイル機能で参照するファイル名<br>　→「3.5 プロファイル機能」|
|3|.doc .txt .bat ...|デフォルトテキスト拡張子<br>　→「3.1 ファイル名の書式」|
|4|File Drive Mask ...|ファイラーメニュー<br>　→「5.2 メニューコマンド」|
|5|0●,◎.○1《 ...|[**GRPH**]+<テンキー>（98版）<br>　→「4.8 その他のコマンド」|
|6|0└,┴.┘1├ ...|[**CTRL**]+<テンキー>による（98版）<br>　→「4.8 その他のコマンド」|
|7|*/;^L|タイトル行サーチのサーチ文字<br>　→「4.1 ページングとタイトルサーチ」|
|8|$6$pd>|非常駐時のコマンドラインプロンプト<br>　→「6.1 コマンドラインの拡張」|
|9|.com .exe .obj ...|デフォルトバイナリー拡張子<br>　→「3.1 ファイル名の書式」|
|10|"$(95,96,9C,9D, ...|ウィンドウ枠、CR,TAB,EOF文字コード|
|11|ﾞﾁｺｿｼｲﾊｷｸﾆﾏﾉﾘﾓ  ...|[カナ]ロック時のメニュー,[**Y**]/[**N**]入力|
|12|"$(00,08,02,0B, ...|パレットテーブル（IBM版）|
|13|"$(03,01,04,05, ...|ファイル属性によるカラー表示|



## ７.５ 起動時オプション一覧

&emsp;VZには、100を越えるオプションがあります。オプションは、DEFファイルの「* O オプション」の箇所で定義してありますが、コマンドラインで「-」をつけて指定することもできます。<br>　オプションは、次のように分類して説明します。<br>
&emsp;　　　**1.起動時オプション**<br>
&emsp;　　　**2.メモリ／バッファサイズ**<br>
&emsp;　　　**3.各種モード**<br>
&emsp;　　　**4.ファイラー関連**<br>
&emsp;　　　**5.表示属性**<br>
&emsp;　　　**6.スイッチ**<br>

●オプションの書式<br>
- 英大文字と小文字は識別しません。
- オプションの後ろの( )の値は初期設定、[** **]は単位です。
- 「*」は、実行中に変更可能なオプションです。
- スイッチの『･･････』は、それを変更するモードメニューです。
- スイッチの項では、特に触れてない限り「+」の場合の効果を説明します。
- Ver1.6で追加／変更されたオプションは、★で示してあります。

●次のオプションVer1.6で廃止されました。<br>

	w		DEFファイルの取り込
	GV		裏グラフィックVRAM使用モード
	Bq		テンポラリファイルのサイズ

&emsp;ただし、指定してもエラーにはなりません。

### ■ 起動時オプション
|記号|説明|
|---|---|
|z|VZを常駐または解放します。|
|r[{n}]|起動後、ただちに番号で指定したマクロを実行します。番号を省略した場合は、ファイルで最初に現れたマクロを実行します。|
|St(-)|読み込むDEFファイルのタイトル行を画面に表示します。|
### ■ メモリ／バッファサイズ
|記号|単位|説明|
|---|---|---|
|Bt(64)|KB|テキストバッファのサイズを設定します。EMSの少ない環境で、大きなファイルを複数個編集する場合は、この値を16にしてください。<br>　　　［範囲］16 ～ 64|
|Bf(64)|KB|DOSコマンド用に確保する最低のメモリサイズを設定します。|
|Bo(32)|KB|コンソール出力バッファのサイズを設定します。「Bo0」でこの機能は使えなくなります。<br>　　　［範囲］0 ～ 32|
|EM(1)||EMSの利用ページ数を設定します。<br>　　　0　　:EMSメモリは使用しない<br>　　　n　　:EMSメモリを最大nページ使用する<br>　　　1　　:EMSメモリの残りを全て使用する|
|★XM(0)|KB|XMSの利用ページ数を設定します。<br>　　　0　　:XMSメモリは使用しない<br>　　　n　　:XMSメモリを最大nKB使用する<br>　　　1　　:XMSメモリの残りを全て使用する<br>　※ EMSとXMSは、合計16MBまで利用できます。|
|Bm(8192)|byte|マクロバッファの空き領域のサイズを設定します。<br>　　　［範囲］256 ～|
|Ba(0)|byte|エイリアスバッファの空き領域のサイズを設定します。|
|Hs(256)|byte|検索文字列ヒストリーバッファの空き領域のサイズを設定します。|
|Hf(256)|byte|ファイル名ヒストリーバッファの空き領域のサイズを設定します。|
|Hx(128)|byte|DOSコマンドラインヒストリーバッファの空き領域のサイズを設定します。|
|Ha(64)|byte|アプリケーションコマンドヒストリーバッファの空き領域のサイズを設定します。|
|Bl(2048)|byte|ラインバッファのサイズを設定します。<br>　　　［範囲］1024 ～ Bt*1024/8|
|Bc(1024)|byte|削除文字列バッファのサイズを設定します。<br>　　　［範囲］256 ～|
|Bu(64)|byte|マクロ用配列・スタック領域のサイズを設定します。<br>　　　［範囲］64 ～|
|★Bv(1024)|byte|ログファイル履歴バッファのサイズを設定します。|
### ■ 各種モード
|記号|説明|
|---|---|
|SW1 *|スワップモードを設定します。<br>　　　0　　:スワップ機能を使用しない<br>　　　1　　:テキスト領域のみ解放する<br>　　　2　　:コード領域も含めて解放する<br>　　　3　　:常駐時に常にコード領域まで解放する<br>　　　4　　:★***SW3***と同様だが、アプリケーションのコマンドラインはフックしない|
|TC(10)|オープン可能なテキスト数を設定します。<br>　　　［範囲］1 ～<br>　　　［メモリ消費］222*TC byte|
|WD(80) *|デフォルトの表示カラム数を設定します。|
|We(80) *|現在編集中のテキストの表示カラム数を設定します。<br>　　　［範囲］2 ～ 250|
|PG(0) *|表示行番号モードでの1ページの行数を設定します。<br>　　　PG-  :ページ表示せず|
|RS(3) *|スムーススクロールの速度を設定します。<br>　　　［範囲］（低速）0 ～ 4（高速）|
|Ta(8) *|タブカラム数を設定します。|
|Tb(4) *|.c .h ファイルのタブカラム数を設定します。<br>　　　［範囲］1,2,4,8,16,32,64|
|Ci(4) *|挿入モード（Insert）時のカーソルの形状を設定します。|
|Co(7) *|上書モード（Overwrite）時のカーソルの形状を設定します。<br>　　　0　　:フルサイズ<br>　　　1　　:1/2 サイズ<br>　　　2　　:1/4 サイズ<br>　　　3　　:アンダーバー<br>　　　+4　　:通常速度の点滅<br>　　　+8　　:1.5倍速度の点滅（98版）<br>　　　+12　　:2倍速の点滅	（98版）|
|WL(0) *|ポップアップウィンドウの表示位置を設定します。<br>　　　+1　　:←よせ<br>　　　+2　　:↑よせ<br>　　　+4　　:Hセンタリング<br>　　　+8　　:Vセンタリング<br>　※ 各モードを設定しない場合は、カーソル位置を基準とすします。|
|LC(-)|編集時の行間空きモードを指定します。（98版）<br>日本語モード時に最下行を予約します。（IBM版）|
|VM0|編集時のスクリーンモードを指定します。（IBM版）|
|★CA(4+16+32)|コントロール文字の色分け<br>　　　+1　　:コントロール文字の「^」<br>　　　+2　　:改行コード「↓」<br>　　　+4　　TABコード「→」<br>　　　+8　　:EOFコード「←」<br>　　　+16　　:右マージン「<」<br>　　　+32　　:全角スペース「□」<br>　　　+64　　:不正なコードの先頭数値|
|★Sr5|プロファイルモードを指定します。<br>　　　+1　　:プロファイル情報のセーブ<br>　　　+2　　:editfile が存在しない場合に、自動作成<br>　　　+4　　:ファイルクローズ時に、ヒストリーに情報を格納<br>　　　+8　　:「vz⏎」で「vz @」の動作<br>　　　+16　　:ログファイルの情報も、ヒストリーに格納<br>　　　+32　　:Command Line ヒストリーも出力する<br>　　　+64　　:ヒストリーを出力しない|
|★Qt0 [秒]|オートセーブのディレイタイムを設定します。0で無効になります。<br>　　　［範囲］0 ～ 3600(sec)|
|★Qc40|オートセーブを起動するまでの入力文字数を設定します。|
### ■ ファイラー関連
|記号|説明|
|---|---|
|★FM7 *|ファイラーの動作モード指定<br>　　　+1　　:[**Space**]キーでカーソルを移動<br>　　　+2　　:ファイル非選択時にもExecメニューを表示<br>　　　+4　　:DOSコマンド』ウィンドウから実行<br>　　　+8　　:ディレクトリの先頭・最後を連続移動|
|FW(1024)|ファイラーで扱うことできるディレクトリの最大数を設定します。|
|FV(1) *|ファイラーのディレクトリ表示モードを設定します。<br>　　　1　　:ロング（縦分割）<br>　　　5　　:ショート（横分割）|
|FS(0) *|ファイラーSortメニューのオプションの初期値を設定します。<br>　　　1　　:ファイル名<br>　　　2　　:拡張子<br>　　　4　　:新しい順<br>　　　8　　:古い順<br>　　　16　　:大きい順<br>　　　32　　:小さい順<br>　　　64　　:ディレクトリを先頭へ|
|FO(3) *|ファイラーCompareメニューのオプションの初期値を設定します。<br>　　　+1　　:存在<br>　　　+2　　:新しいファイル<br>　　　+4　　:古いファイル<br>　　　+8　　:大きいファイル<br>　　　+16　　:小さいファイル|
### ■ 表示属性
|記号|説明|
|---|---|
|An(7) *|通常のテキスト|
|Ac(5) *|テキストのCR,TAB,EOF文字|
|Al(5) *|行番号|
|Ah(13) *|ブロック領域|
|As(15) *|ステータスライン|
|Ao(14) *|コンソールファイルのステータスライ|
|Ar(13) *|Read onlyファイルのステータスライン|
|Am(6) *|最下行のメッセージ|
|Ab(5) *|ウィンドウわく|
|At(5) *|ウィンドウタイトル|
|Aw(7) *|ウィンドウメニュー|
|Af(6) *|ウィンドウメニューのダイレクトキー|
|Ai(15) *|ウィンドウメニューのカーソル|
|Aj(6) *|ヘルプウィンドウ|
|Ak(6) *|2ストローク先頭キー|
|Ag(1) *|ファイラーの背景|
|Au(6) *|ファイラーのカーソル|
|Ap($70) * |ファンクションキー（IBM版）|
|★Ae(1) *|CR,TAB,EOF文字の2番目のカラー|
|★Ay(0) *|ステータスラインのファイル名|

**【98版】**<br>
&emsp;　　　0:黒 1:青 2:赤 3:紫 4:緑 5:水色 6:黄 7:白<br>
&emsp;　　　+8:リバース +16:アンダーライン<br>
**【J-3100版】**<br>
&emsp;　　　6:ボールド 7:ノーマル +$70:リバース +8:アンダーライン<br>
**【IBMカラー】**<br>
&emsp;　　　0:黒 1:青 2:緑 3:水色 4:赤 5:紫 6:黄 7:白 （低輝度）<br>
&emsp;　　　8:黒 9:青 $A:緑 $B:水色 $C:赤 $D:紫 $E:黄 $F:白 （高輝度）<br>
&emsp;　　　　　背景色はx16<br>
**【IBMモノクロ】**<br>
&emsp;　　　0:黒 7:白 +8:高輝度／ボールド +$70:背景白<br>
### ■ スイッチ
|記号|説明|
|---|---|
|Dl(-) *|行番号を表示します。<br>　　　『L 行番号の表示』|
|Dc(+) *|CR 文字を表示します。<br>　　　『C CR の表示』|
|Dt(-) *|TAB文字を表示します。<br>　　　『T TABの表示』|
|De(+) *|EOF文字を表示します。<br>　　　『E EOFの表示』|
|Ds(-) *|ステータスラインへシステム情報を表示します。<br>　　　『S システム情報の表示』|
|Db(-) *|￥文字をバックスラッシュ（＼）で表示します。（98版）<br>　　　『¥ バックスラッシュ』<br>　※ 一部の機種では使えません。|
|Dn(-) *|行番号モードを切り替えます。<br>　　　Dn-　　:論理行番号<br>　　　改行コード（0Ah）から次の改行コードまでを1行とした時の行番号。<br>　　　Dn+　　:表示行番号<br>　　　画面上に表示される1行をそのまま1行とした時の行番号<br>　　　『N 行番号モード』|
|Du(-) *|カーソル行アンダーラインを表示します。<br>　　　『U アンダーライン』|
|Df(-) *|編集ファイル名を、フルパス名で表示します。|
|Dp(-) *|全てのファイル名・パス名を小文字で表示します。|
|Dh(-) *|ファイル名をステータスラインの左側に表示します。|
|Dg(+) *|新JIS罫線文字を表示します。（98版）|
|Dg(+) *|スクロール時の最上行の"ぶれ"を軽減します.（DOS／V版）|
|★Dr(+) *|「we<80」の時、右マージンを表示します。|
|★Dv(-) *|スムーススクロール時、カラーでスクロールします。|
|Ei(+) *|オートインデントを指定します。<br>　　　『A オートインデント』|
|Es(+) *|[**Ctrl**]+[↑][↓]を画面上端／下端で実行した時にスムーススクロールを起動します。|
|Ez(+) *|書き込むファイルの最後に、EOFコード（1Ah）を付加します。|
|Eb(+) *|ファイルの書き込み時に、バックアップファイルを作成します。<br>　　　『B .BAK ファイルの作成』|
|Eu(-) *|[**TAB**]をスペースに変換して入力します。|
|Et(+) *|論理ページング機能（Cモード）を使用します。|
|Eh(-) *|ページング（Pモード）の画面単位を切り替えます。<br>　　　Eh-　　:全画面<br>　　　Eh+　　:半画面<br>　　　『H ページング単位』|
|Ew(+) *|文字列検索時のデフォルトをワードサーチにします。<br>　　　『W ワードサーチ』|
|Ec(-) *|文字列検索時に英大文字と小文字の違いを無視します。<br>　　　『C 検索時の英大/小文字』|
|Ex(-) *|テキストスタックが一杯になった時、警告します。|
|En(-) *|カーソルを改行以降に表示させなくします。|
|Ev(-) *|ジャンプ後、カーソルを画面の中央へ移動します。|
|Ek(-) *|ブロック挿入後、カーソルをブロックの最後に移動します。|
|Ea(-) *|オープンしたファイルの拡張子が数字の場合、表示カラム数をその値に設定します。|
|RO(-) *|Viewモードでオープンします。|
|Ej(-) *|全角スペースもオートインデントします。|
|Eo(-) *|上書きモードを桁対応に設定します。<br>　　　『O 上書きモード』|
|RX(-) *|正規表現検索を有効にします。（VWX.COM常駐時）<br>　　　『X 正規表現』|
|ZH(-) *|検索時に全角／半角文字を同一視します。（VWX.COM常駐時）<br>　　　『Z 全角/半角文字』|
|Sx(+) *|DOSコンソール出力の取込みを行ないます。|
|Se(+) *|DOSコンソール出力の取込み時に、エスケープシーケンスをスキップします。|
|Sd(+) *|DOSコマンドを実行前にエイリアスで展開して再表示します。|
|Sk(-) *|DOSコマンド実行前に、テキストスタックをクリアします。|
|Sy(-) *|(Y/N)入力時、⏎=Yes, [**Space**]=No になります。|
|★YN(-) *|(Y/N)入力時、⏎=No, [**Space**]=Yes になります。|
|Sn(+) *|編集ファイルが見つからない場合の確認動作を指定します。<br>　　　「***Sn-***」:ただちに新規ファイルとしてオープン<br>　　　「***Sn+***」:新規ファイルかどうか確認|
|Sq(-) *|[**ESC**][**C**],[**ESC**][**Q**]コマンドで即座にエディタを終了します。|
|FP(-)|FEP（VJEβ、松茸、ATOK）を制御します。|
|FR(-)|起動後ただちにFEPをONします。（起動モードを引数で指定）|
|FK(-)|[**F11**]～[**F15**]と[**Ctrl**]+[**F･n**]を有効にします。（98版）<br>12個のファンクションキーを表示し、ATの拡張キーBIOSを使用します。（IBM版）|
|★Sz- *|常駐時の編集終了時に、オプションを初期化します。アプリケーションから常駐しているVZを起動する時に指定します。|


